# 🗂️ Beekeeper 🐝

![PyPI - Version](https://img.shields.io/pypi/v/beekeeper-ai)
[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)
![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)
![Pepy Total Downloads](https://img.shields.io/pepy/dt/beekeeper-ai)
![PyPI - License](https://img.shields.io/pypi/l/beekeeper-ai)

## Installation 

```bash
pip install beekeeper-ai
```

## 📄 Documentation

The documentation can be found Click [here](https://beekeeper-ai.github.io/beekeeper/)!

Please check it out for overview of the interfaces, components, integrations and other resources!
